@@ -1124,14 +1124,18 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
         1.00000f
     };
 
-    FILE* const file = g_fopen(filename.c_str(), "rb");
+    const std::unique_ptr<std::FILE, std::function<void(std::FILE *)>> file(
+        g_fopen(filename.c_str(), "rb"),
+        [](std::FILE *file) {
+            std::fclose(file);
+        });
 
     if (file == nullptr) {
         printf ("Unable to load DCP profile '%s' !", filename.c_str());
         return;
     }
 
-    DCPMetadata md(file);
+    DCPMetadata md(file.get());
     if (!md.parse()) {
         printf ("Unable to load DCP profile '%s'.", filename.c_str());
         return;
@@ -1173,8 +1177,9 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
 
     // Color Matrix (one is always there)
     if (!md.find(TAG_KEY_COLOR_MATRIX_1)) {
-        std::cerr << "DCP '" << filename << "' is missing 'ColorMatrix1'. Skipped." << std::endl;
-        fclose(file);
+        if (settings->verbose) {
+            std::cerr << "DCP '" << filename.c_str() << "' is missing 'ColorMatrix1'. Skipped." << std::endl;
+        }
         return;
     }
 
@@ -1351,10 +1356,6 @@ DCPProfile::DCPProfile(const Glib::ustring& filename) :
         }
     }
 
-    if (file) {
-        fclose(file);
-    }
-
     valid = true;
 }
 
