@@ -878,7 +878,7 @@ void RawImageSource::nodemosaic(bool bw)
         for (int j = 0; j < W; j++) {
             if (bw) {
                 red[i][j] = green[i][j] = blue[i][j] = rawData[i][j];
-            } else if(ri->getSensorType() != ST_FUJI_XTRANS) {
+            } else if(ri->getSensorType() == ST_BAYER) {
                 switch( FC(i, j)) {
                 case 0:
                     red[i][j] = rawData[i][j];
@@ -895,7 +895,7 @@ void RawImageSource::nodemosaic(bool bw)
                     red[i][j] = green[i][j] = 0;
                     break;
                 }
-            } else {
+            } else if(ri->getSensorType() == ST_FUJI_XTRANS) {
                 switch( ri->XTRANSFC(i, j)) {
                 case 0:
                     red[i][j] = rawData[i][j];
@@ -912,6 +912,10 @@ void RawImageSource::nodemosaic(bool bw)
                     red[i][j] = green[i][j] = 0;
                     break;
                 }
+            } else {
+                red[i][j] = rawData[i][j * 3 + 0];
+                green[i][j] = rawData[i][j * 3 + 1];
+                blue[i][j] = rawData[i][j * 3 + 2];
             }
         }
     }
@@ -972,11 +976,11 @@ inline void RawImageSource::dcb_initTileLimits(int &colMin, int &rowMin, int &co
     }
 
     if( y0 + TILESIZE + TILEBORDER >= H - border) {
-        rowMax = TILEBORDER + H - border - y0;
+        rowMax = std::min(TILEBORDER + H - border - y0, rowMax);
     }
 
     if( x0 + TILESIZE + TILEBORDER >= W - border) {
-        colMax = TILEBORDER + W - border - x0;
+        colMax = std::min(TILEBORDER + W - border - x0, colMax);
     }
 }
 
@@ -1069,7 +1073,7 @@ void RawImageSource::dcb_hid(float (*image)[3], int x0, int y0)
         for (int col = colMin + (FC(y0 - TILEBORDER + row, x0 - TILEBORDER + colMin) & 1), indx = row * CACHESIZE + col; col < colMax; col += 2, indx += 2) {
             assert(indx - u - 1 >= 0 && indx + u + 1 < u * u);
 
-            image[indx][1] = 0.25*(image[indx-1][1]+image[indx+1][1]+image[indx-u][1]+image[indx+u][1]);
+            image[indx][1] = 0.25f * (image[indx-1][1]+image[indx+1][1]+image[indx-u][1]+image[indx+u][1]);
         }
 }
 
