@@ -317,7 +317,6 @@ private:
     typedef std::map<std::string, std::vector<badPix> > bpList_t;
     dfList_t dfList;
     bpList_t bpList;
-    bool initialized;
     Glib::ustring currentPath;
     dfInfo* addFileInfo(const Glib::ustring &filename, bool pool = true);
     dfInfo* find(const std::string &mak, const std::string &mod, int isospeed, double shut, time_t t);
@@ -569,7 +568,7 @@ dfInfo* rtengine::DFManager::Implementation::addFileInfo(const Glib::ustring& fi
             return &(iter->second);
         }
 
-        FramesData idata(filename, std::unique_ptr<RawMetaDataLocation>(new RawMetaDataLocation(ri.get_exifBase(), ri.get_ciffBase(), ri.get_ciffLen())), true);
+        FramesData idata(filename);
         /* Files are added in the map, divided by same maker/model,ISO and shutter*/
         std::string key(dfInfo::key(toUppercase(idata.getMake()), toUppercase(idata.getModel()), idata.getISOSpeed(), idata.getShutterSpeed()));
         auto iter = dfList.find(key);
