@@ -305,6 +305,7 @@ protected:
     LocLLmaskCurve locllmasCurve;
     LocHHmaskCurve lochhmasCurve;
     LocHHmaskCurve lochhhmasCurve;
+    LocHHmaskCurve lochhhmascieCurve;
     LocCCmaskCurve locccmasexpCurve;
     LocLLmaskCurve locllmasexpCurve;
     LocHHmaskCurve lochhmasexpCurve;
@@ -343,6 +344,7 @@ protected:
     LocwavCurve locwavCurve;
     LocwavCurve loclmasCurveblwav;
     LocwavCurve loclmasCurvecolwav;
+    LocwavCurve loclmasCurveciewav;
     LocwavCurve loclevwavCurve;
     LocwavCurve locconwavCurve;
     LocwavCurve loccompwavCurve;
