@@ -44,6 +44,7 @@ const Settings* settings;
 
 MyMutex* lcmsMutex = nullptr;
 MyMutex *fftwMutex = nullptr;
+MyMutex *librawMutex = nullptr;
 
 int init (const Settings* s, const Glib::ustring& baseDir, const Glib::ustring& userSettingsDir, bool loadAll)
 {
@@ -120,6 +121,8 @@ int init (const Settings* s, const Glib::ustring& baseDir, const Glib::ustring&
     delete lcmsMutex;
     lcmsMutex = new MyMutex;
     fftwMutex = new MyMutex;
+    delete librawMutex;
+    librawMutex = new MyMutex;
     return 0;
 }
 
