@@ -27,32 +27,51 @@
 #include "labimage.h"
 #include "improcfun.h"
 #include "procparams.h"
+#include "settings.h"
 
 namespace rtengine
 {
 
-void ImProcFunctions::localContrast(LabImage *lab)
+void ImProcFunctions::localContrast(LabImage *lab, float **destination, const rtengine::procparams::LocalContrastParams &localContrastParams, bool fftwlc, double scale)
 {
-    if (!params->localContrast.enabled) {
+    if (!localContrastParams.enabled) {
         return;
     }
 
     const int width = lab->W;
     const int height = lab->H;
-    const float a = params->localContrast.amount;
-    const float dark = params->localContrast.darkness;
-    const float light = params->localContrast.lightness;
+    const float a = localContrastParams.amount;
+    const float dark = localContrastParams.darkness;
+    const float light = localContrastParams.lightness;
     array2D<float> buf(width, height);
-    const float sigma = params->localContrast.radius / scale;
-
+    float sigma = localContrastParams.radius / scale;
+    //printf("wi%i he=%i am=%f da=%f li=%f si=%f\n", width, height, a, dark, light, sigma);
+    if(!fftwlc) {
 #ifdef _OPENMP
-    #pragma omp parallel if(multiThread)
+        #pragma omp parallel if(multiThread)
 #endif
-    gaussianBlur(lab->L, buf, width, height, sigma);
-
+        gaussianBlur(lab->L, buf, width, height, sigma);
+    } else {
+        float kr = 1.f;
+        //emprical adjustment between FFTW radius and Gaussainblur
+        //under 50 ==> 10.f
+        //above 400 ==> 1.f
+        if(settings->fftwsigma == false) {//empirical formula
+            float ak = -9.f / 350.f;
+            float bk = 10.f - 50.f * ak;
+            kr = ak * sigma + bk;
+            if(sigma < 50.f) kr = 10.f;
+            if(sigma > 400.f) kr = 1.f;
+        } else {//sigma *= sigma
+            kr = sigma;
+        }
+        //OPENMP disabled
+        ImProcFunctions::fftw_convol_blur2(lab->L, buf, width, height, kr * sigma, 0, 0);
+    }
 #ifdef _OPENMP
     #pragma omp parallel for if(multiThread)
 #endif
+
     for (int y = 0; y < height; ++y) {
         for (int x = 0; x < width; ++x) {
             float bufval = (lab->L[y][x] - buf[y][x]) * a;
@@ -61,7 +80,7 @@ void ImProcFunctions::localContrast(LabImage *lab)
                 bufval *= (bufval > 0.f) ? light : dark;
             }
 
-            lab->L[y][x] = std::max(0.0001f, lab->L[y][x] + bufval);
+            destination[y][x] = LIM(lab->L[y][x] + bufval, 0.0001f, 32767.f);
         }
     }
 }
