@@ -1,5 +1,4 @@
-#ifndef _RT_JPEG_H
-#define _RT_JPEG_H
+#pragma once
 
 #include <csetjmp>
 
@@ -29,6 +28,3 @@ typedef struct {
 #ifdef __cplusplus
 }
 #endif
-
-
-#endif
