@@ -1108,7 +1108,7 @@ enum ProcEventCode {
     Evlocallabsigmoidldacie = 1078,
     Evlocallabsigmoidthcie = 1079,
     Evlocallabsigmoidblcie = 1080,
-    Evlocallabsigmoidqjcie = 1081,
+    Evlocallabcomprcieauto = 1081,
     Evlocallabhuecie = 1082,
     Evlocallabjabcie = 1083,
     Evlocallablightjzcie = 1084,
@@ -1177,6 +1177,7 @@ enum ProcEventCode {
     Evlocallabsigjz = 1147,
     Evlocallabsigq = 1148,
     Evlocallablogcie = 1149,
+
     NUMOFEVENTS
 };
 
