@@ -23,17 +23,18 @@
 #include "procevents.h"
 
 // Use M_VOID if you wish to update the proc params without updating the preview at all !
-#define M_VOID       (1<<17)
+#define M_VOID       (1<<20)
 // Use M_MINUPDATE if you wish to update the preview without modifying the image (think about it like a "refreshPreview")
 // Must NOT be used with other event (i.e. will be used for MINUPDATE only)
-#define M_MINUPDATE  (1<<16)
+#define M_MINUPDATE  (1<<19)
 // Force high quality
-#define M_HIGHQUAL   (1<<15)
+#define M_HIGHQUAL   (1<<18)
 
 // Elementary functions that can be done to
 // the preview image when an event occurs
-#define M_SPOT        (1<<19)
-#define M_CSHARP      (1<<18)
+#define M_WB          (1<<17)
+#define M_SPOT        (1<<16)
+#define M_CSHARP      (1<<15)
 #define M_MONITOR     (1<<14)
 #define M_RETINEX     (1<<13)
 #define M_CROP        (1<<12)
@@ -57,6 +58,7 @@
 #define DARKFRAME        (M_PREPROC|M_RAW|M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
 #define FLATFIELD        (M_PREPROC|M_RAW|M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
 #define DEMOSAIC                   (M_RAW|M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
+#define WB                          (M_WB|M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
 #define ALLNORAW                         (M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
 #define CAPTURESHARPEN                   (M_INIT|M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR|M_CSHARP)
 #define HDR                                     (M_SPOT|M_LINDENOISE|M_HDR|M_TRANSFORM|M_BLURMAP|M_AUTOEXP|M_RGBCURVE|M_LUMACURVE|M_LUMINANCE|M_COLOR)
