@@ -10,6 +10,9 @@ enum {
     ADDSET_SH_HIGHLIGHTS,
     ADDSET_SH_SHADOWS,
     ADDSET_SH_LOCALCONTRAST, // not used anymore
+    ADDSET_TONE_EQUALIZER_BANDS,
+    ADDSET_TONE_EQUALIZER_PIVOT,
+    ADDSET_TONE_EQUALIZER_REGULARIZATION,
     ADDSET_LC_BRIGHTNESS,
     ADDSET_LC_CONTRAST,
     ADDSET_SHARP_AMOUNT,
@@ -65,6 +68,8 @@ enum {
     ADDSET_CAT_CHROMA_S,
     ADDSET_CAT_CHROMA_M,
     ADDSET_CAT_HUE,
+    ADDSET_CAT_DEGREEOUT,
+    ADDSET_CAT_TEMPOUT,
     ADDSET_CAT_BADPIX,
     ADDSET_WB_EQUAL,
     ADDSET_GRADIENT_DEGREE,
