@@ -29,6 +29,7 @@
 #include "../rtengine/noncopyable.h"
 
 class Thumbnail;
+class RTSurface;
 
 namespace rtengine
 {
@@ -61,7 +62,7 @@ class BatchQueueEntry final : public ThumbBrowserEntryBase, public BQEntryUpdate
 
 public:
 
-    static Glib::RefPtr<Gdk::Pixbuf> savedAsIcon;
+    static std::shared_ptr<RTSurface> savedAsIcon;
 
     rtengine::ProcessingJob* job;
     const std::unique_ptr<rtengine::procparams::ProcParams> params;
@@ -84,7 +85,7 @@ public:
 
     void removeButtonSet ();
 
-    std::vector<Glib::RefPtr<Gdk::Pixbuf>> getIconsOnImageArea () override;
+    std::vector<std::shared_ptr<RTSurface>> getIconsOnImageArea () override;
     void getIconSize (int& w, int& h) const override;
     std::tuple<Glib::ustring, bool> getToolTip (int x, int y) const override;
 
