@@ -32,10 +32,10 @@ const Glib::ustring CACorrection::TOOL_NAME = "cacorrection";
 CACorrection::CACorrection () : FoldableToolPanel(this, TOOL_NAME, M("TP_CACORRECTION_LABEL"))
 {
 
-    Gtk::Image* icaredL =   Gtk::manage (new RTImage ("circle-red-cyan-small.png"));
-    Gtk::Image* icaredR =   Gtk::manage (new RTImage ("circle-cyan-red-small.png"));
-    Gtk::Image* icablueL =  Gtk::manage (new RTImage ("circle-blue-yellow-small.png"));
-    Gtk::Image* icablueR =  Gtk::manage (new RTImage ("circle-yellow-blue-small.png"));
+    Gtk::Image* icaredL =   Gtk::manage (new RTImage ("circle-red-cyan-small"));
+    Gtk::Image* icaredR =   Gtk::manage (new RTImage ("circle-cyan-red-small"));
+    Gtk::Image* icablueL =  Gtk::manage (new RTImage ("circle-blue-yellow-small"));
+    Gtk::Image* icablueR =  Gtk::manage (new RTImage ("circle-yellow-blue-small"));
 
     red = Gtk::manage (new Adjuster (M("TP_CACORRECTION_RED"), -0.005, 0.005, 0.0001, 0, icaredL, icaredR));
     red->setAdjusterListener (this);
