@@ -235,7 +235,7 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     genFrame->set_tooltip_markup (M ("TP_COLORAPP_GEN_TOOLTIP"));
     genVBox = Gtk::manage ( new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
     genVBox->set_spacing (2);
-    
+
     complexmethod = Gtk::manage (new MyComboBoxText ());
     complexmethod->append(M("TP_WAVELET_COMPNORMAL"));
     complexmethod->append(M("TP_WAVELET_COMPEXPERT"));
@@ -246,7 +246,7 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     complexHBox->pack_start(*complexLabel, Gtk::PACK_SHRINK, 4);
     complexHBox->pack_start(*complexmethod);
     genVBox->pack_start (*complexHBox, Gtk::PACK_SHRINK);
-    
+
     modelmethod = Gtk::manage (new MyComboBoxText ());
     modelmethod->append(M("TP_COLORAPP_MOD02"));
     modelmethod->append(M("TP_COLORAPP_MOD16"));
@@ -269,7 +269,7 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     catHBox->pack_start(*catLabel, Gtk::PACK_SHRINK, 4);
     catHBox->pack_start(*catmethod);
     genVBox->pack_start (*catHBox, Gtk::PACK_SHRINK);
-    
+
 
     genFrame->add (*genVBox);
     pack_start (*genFrame, Gtk::PACK_EXPAND_WIDGET, 4);
@@ -321,7 +321,7 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
 
 
     wbmHBox = Gtk::manage (new Gtk::Box ());
-    
+
     wbmHBox->set_spacing (2);
     wbmHBox->set_tooltip_markup (M ("TP_COLORAPP_MODEL_TOOLTIP"));
     Gtk::Label* wbmLab = Gtk::manage (new Gtk::Label (M ("TP_COLORAPP_MODEL") + ":"));
@@ -355,10 +355,10 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     illumHBox->pack_start (*illum);
     p1VBox->pack_start (*illumHBox);
 
-    Gtk::Image* itempL =  Gtk::manage (new RTImage ("circle-blue-small.png"));
-    Gtk::Image* itempR =  Gtk::manage (new RTImage ("circle-yellow-small.png"));
-    Gtk::Image* igreenL = Gtk::manage (new RTImage ("circle-magenta-small.png"));
-    Gtk::Image* igreenR = Gtk::manage (new RTImage ("circle-green-small.png"));
+    Gtk::Image* itempL =  Gtk::manage (new RTImage ("circle-blue-small"));
+    Gtk::Image* itempR =  Gtk::manage (new RTImage ("circle-yellow-small"));
+    Gtk::Image* igreenL = Gtk::manage (new RTImage ("circle-magenta-small"));
+    Gtk::Image* igreenR = Gtk::manage (new RTImage ("circle-green-small"));
 
 
     tempsc = Gtk::manage (new Adjuster (M ("TP_WBALANCE_TEMPERATURE"), MINTEMP0, MAXTEMP0, 5, CENTERTEMP0, itempL, itempR, &wbSlider2Temp, &wbTemp2Slider));
@@ -646,10 +646,10 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     p3VBox = Gtk::manage ( new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
     p3VBox->set_spacing (2);
 
-    Gtk::Image* itempL1 =  Gtk::manage (new RTImage ("circle-blue-small.png"));
-    Gtk::Image* itempR1 =  Gtk::manage (new RTImage ("circle-yellow-small.png"));
-    Gtk::Image* igreenL1 = Gtk::manage (new RTImage ("circle-magenta-small.png"));
-    Gtk::Image* igreenR1 = Gtk::manage (new RTImage ("circle-green-small.png"));
+    Gtk::Image* itempL1 =  Gtk::manage (new RTImage ("circle-blue-small"));
+    Gtk::Image* itempR1 =  Gtk::manage (new RTImage ("circle-yellow-small"));
+    Gtk::Image* igreenL1 = Gtk::manage (new RTImage ("circle-magenta-small"));
+    Gtk::Image* igreenR1 = Gtk::manage (new RTImage ("circle-green-small"));
     adaplum = Gtk::manage (new Adjuster (M ("TP_COLORAPP_ABSOLUTELUMINANCE"), MINLA0, MAXLA0, 0.01, 16.));//, NULL, NULL, &wbSlider2la, &wbla2Slider));
     adaplum->setLogScale(500, 0);
 
@@ -659,8 +659,8 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     adaplum->set_tooltip_markup (M ("TP_COLORAPP_VIEWING_ABSOLUTELUMINANCE_TOOLTIP"));
     p3VBox->pack_start (*adaplum);
 
-//   Gtk::Image* iblueredL = Gtk::manage (new RTImage ("circle-blue-small.png"));
-//   Gtk::Image* iblueredR = Gtk::manage (new RTImage ("circle-red-small.png"));
+//   Gtk::Image* iblueredL = Gtk::manage (new RTImage ("circle-blue-small"));
+//   Gtk::Image* iblueredR = Gtk::manage (new RTImage ("circle-red-small"));
 
     degreeout  = Gtk::manage (new Adjuster (M ("TP_COLORAPP_CIECAT_DEGREEOUT"),    0.,  100.,  1.,   90.));
 
@@ -672,10 +672,10 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     degreeout->addAutoButton (M ("TP_COLORAPP_CAT02ADAPTATION_TOOLTIP"));
     p3VBox->pack_start (*degreeout);
     /*
-        Gtk::Image* itempL1 =  Gtk::manage (new RTImage ("circle-blue-small.png"));
-        Gtk::Image* itempR1 =  Gtk::manage (new RTImage ("circle-yellow-small.png"));
-        Gtk::Image* igreenL1 = Gtk::manage (new RTImage ("circle-magenta-small.png"));
-        Gtk::Image* igreenR1 = Gtk::manage (new RTImage ("circle-green-small.png"));
+        Gtk::Image* itempL1 =  Gtk::manage (new RTImage ("circle-blue-small"));
+        Gtk::Image* itempR1 =  Gtk::manage (new RTImage ("circle-yellow-small"));
+        Gtk::Image* igreenL1 = Gtk::manage (new RTImage ("circle-magenta-small"));
+        Gtk::Image* igreenR1 = Gtk::manage (new RTImage ("circle-green-small"));
     */
     tempout = Gtk::manage (new Adjuster (M ("TP_WBALANCE_TEMPERATURE"), MINTEMP0, MAXTEMP0, 5, CENTERTEMP0, itempR1, itempL1, &wbSlider2Temp, &wbTemp2Slider));
     greenout = Gtk::manage (new Adjuster (M ("TP_WBALANCE_GREEN"), MINGREEN0, MAXGREEN0, 0.001, 1.0, igreenR1, igreenL1));
@@ -746,7 +746,7 @@ ColorAppearance::ColorAppearance () : FoldableToolPanel (this, TOOL_NAME, M ("TP
     //reset button
     neutral = Gtk::manage (new Gtk::Button (M ("TP_COLORAPP_NEUTRAL")));
     setExpandAlignProperties (neutral, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
-    RTImage *resetImg = Gtk::manage (new RTImage ("undo-small.png", "redo-small.png"));
+    RTImage* const resetImg = Gtk::manage (new RTImage ("undo-small", Gtk::ICON_SIZE_BUTTON));
     setExpandAlignProperties (resetImg, false, false, Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER);
     neutral->set_image (*resetImg);
     neutral->set_tooltip_text (M ("TP_COLORAPP_NEUTRAL_TOOLTIP"));
@@ -888,8 +888,9 @@ void ColorAppearance::read (const ProcParams* pp, const ParamsEdited* pedited)
     curveMode3Changed(); // This will set the correct sensitive state of depending Adjusters
 
     nexttemp = pp->wb.temperature;
-    nextgreen = 1.; //pp->wb.green;
-    
+    //nextgreen = 1.; //pp->wb.green;
+    nextgreen = pp->wb.green;
+
     if (pedited) {
         degree->setEditedState        (pedited->colorappearance.degree ? Edited : UnEdited);
         degreeout->setEditedState        (pedited->colorappearance.degreeout ? Edited : UnEdited);
@@ -961,7 +962,7 @@ void ColorAppearance::read (const ProcParams* pp, const ParamsEdited* pedited)
     } else if (pp->colorappearance.complexmethod == "expert") {
         complexmethod->set_active(1);
     }
-    
+
     modelmethod->set_active(0);
 
     if (pp->colorappearance.modelmethod == "02") {
@@ -1368,11 +1369,11 @@ void ColorAppearance::updateGUIToMode(int mode)
         curveEditorG3->hide();
         //greenout->hide();
         greenout->set_sensitive(false);
-		
+
         badpixsl->hide();
         datacie->hide();
     } else {
-        alHBox->show(); 
+        alHBox->show();
         wbmHBox->show();
         curveEditorG->show();
         curveEditorG2->show();
@@ -1411,7 +1412,7 @@ void ColorAppearance::convertParamToNormal()
 }
 
 void ColorAppearance::complexmethodChanged()
-{    
+{
     if (complexmethod->get_active_row_number() == 0) {
         updateGUIToMode(0);
         convertParamToNormal();
@@ -1426,7 +1427,7 @@ void ColorAppearance::complexmethodChanged()
 }
 
 void ColorAppearance::modelmethodChanged()
-{    
+{
 
     if (listener && (multiImage || getEnabled())) {
         listener->panelChanged(EvCATmodel, modelmethod->get_active_text());
@@ -1434,7 +1435,7 @@ void ColorAppearance::modelmethodChanged()
 }
 
 void ColorAppearance::catmethodChanged()
-{    
+{
 
     if (catmethod->get_active_row_number() == 1) {
         disableListener();
@@ -1483,7 +1484,7 @@ void ColorAppearance::catmethodChanged()
         degreeout->setValue(90);
         ybout->setValue(18);
         tempout->setValue (nexttemp);
-    
+
         if(tempout->getAutoValue()) {
             tempout->resetValue (false);
             tempout->setAutoValue (true);
@@ -1495,7 +1496,7 @@ void ColorAppearance::catmethodChanged()
 
         greenout->setValue (nextgreen);
         enableListener();
-    
+
     }  else if (catmethod->get_active_row_number() == 0) {
         disableListener();
         degree->setAutoValue (true);
@@ -1519,7 +1520,7 @@ void ColorAppearance::catmethodChanged()
         ybout->resetValue (false);
         tempout->resetValue (false);
         tempout->setAutoValue (true);
-        greenout->resetValue (false);
+        greenout->resetValue (true);
         enableListener();
     }  else if (catmethod->get_active_row_number() == 2) {
         disableListener();
@@ -1866,7 +1867,7 @@ void ColorAppearance::autoCamChanged (double ccam, double ccamout)
 
 void ColorAppearance::adapCamChanged (double cadap)
 {
-    
+
     idle_register.add(
         [this, cadap]() -> bool
         {
@@ -1879,16 +1880,36 @@ void ColorAppearance::adapCamChanged (double cadap)
 }
 
 
-void ColorAppearance::wbCamChanged (double temp, double tin)
+void ColorAppearance::wbCamChanged (double temp, double tin, bool autotemp)
 {//reactivate this function
-    
+
     idle_register.add(
-        [this, temp, tin]() -> bool
+        [this, temp, tin, autotemp]() -> bool
+
         {
+            if (temp != tempout->getValue()) {
+                disableListener();
+                tempout->setValue(temp);
+                enableListener();
+                listener->panelChanged (EvCATtempout, tempout->getTextValue());
+            }
+            if (tin != greenout->getValue()) {
+                disableListener();
+                greenout->setValue(tin);
+                enableListener();
+                listener->panelChanged (EvCATgreenout, greenout->getTextValue());
+            }
+            /*
             disableListener();
             tempout->setValue(temp);
-			greenout->setValue(tin);
+            greenout->setValue(tin);
             enableListener();
+
+            if(!autotemp) {
+                listener->panelChanged (EvCATgreenout, "");//greenout->getTextValue());
+                listener->panelChanged (EvCATtempout, "");//tempout->getTextValue());
+            }*/
+
             return false;
         }
     );
@@ -2124,7 +2145,7 @@ void ColorAppearance::wbmodelChanged ()
         tempsc->hide();
         greensc->hide();
         tempsc->setValue (5003);
-        greensc->setValue (1);   
+        greensc->setValue (1);
     }
 
     if (wbmodel->get_active_row_number() == 2) {
