@@ -85,18 +85,18 @@ DiagonalCurveEditorSubGroup::DiagonalCurveEditorSubGroup (CurveEditorGroup* prt,
     }
 
     editPointCustom = Gtk::manage (new Gtk::ToggleButton ());
-    initButton(*editPointCustom, Glib::ustring("edit-point.png"), Gtk::ALIGN_START, false, "CURVEEDITOR_EDITPOINT_HINT");
+    initButton(*editPointCustom, Glib::ustring("edit-point"), Gtk::ALIGN_START, false, "CURVEEDITOR_EDITPOINT_HINT");
     editCustom = Gtk::manage (new Gtk::ToggleButton());
-    initButton(*editCustom, Glib::ustring("crosshair-node-curve.png"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
+    initButton(*editCustom, Glib::ustring("crosshair-node-curve"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
     editCustom->hide();
     copyCustom = Gtk::manage (new Gtk::Button ());
-    initButton(*copyCustom, Glib::ustring("copy.png"), Gtk::ALIGN_END, true);
+    initButton(*copyCustom, Glib::ustring("copy"), Gtk::ALIGN_END, true);
     pasteCustom = Gtk::manage (new Gtk::Button ());
-    initButton(*pasteCustom, Glib::ustring("paste.png"), Gtk::ALIGN_END, false);
+    initButton(*pasteCustom, Glib::ustring("paste"), Gtk::ALIGN_END, false);
     loadCustom = Gtk::manage (new Gtk::Button ());
-    initButton(*loadCustom, Glib::ustring("folder-open.png"), Gtk::ALIGN_END, false);
+    initButton(*loadCustom, Glib::ustring("folder-open"), Gtk::ALIGN_END, false);
     saveCustom = Gtk::manage (new Gtk::Button ());
-    initButton(*saveCustom, Glib::ustring("save.png"), Gtk::ALIGN_END, false);
+    initButton(*saveCustom, Glib::ustring("save"), Gtk::ALIGN_END, false);
 
     custombbox->attach_next_to(*editPointCustom, sideStart, 1, 1);
     custombbox->attach_next_to(*editCustom,      sideStart, 1, 1);
@@ -177,18 +177,18 @@ DiagonalCurveEditorSubGroup::DiagonalCurveEditorSubGroup (CurveEditorGroup* prt,
     }
 
     editPointNURBS = Gtk::manage (new Gtk::ToggleButton ());
-    initButton(*editPointNURBS, Glib::ustring("edit-point.png"), Gtk::ALIGN_START, false, "CURVEEDITOR_EDITPOINT_HINT");
+    initButton(*editPointNURBS, Glib::ustring("edit-point"), Gtk::ALIGN_START, false, "CURVEEDITOR_EDITPOINT_HINT");
     editNURBS = Gtk::manage (new Gtk::ToggleButton());
-    initButton(*editNURBS, Glib::ustring("crosshair-node-curve.png"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
+    initButton(*editNURBS, Glib::ustring("crosshair-node-curve"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
     editNURBS->hide();
     copyNURBS = Gtk::manage (new Gtk::Button ());
-    initButton(*copyNURBS, Glib::ustring("copy.png"), Gtk::ALIGN_END, true);
+    initButton(*copyNURBS, Glib::ustring("copy"), Gtk::ALIGN_END, true);
     pasteNURBS = Gtk::manage (new Gtk::Button ());
-    initButton(*pasteNURBS, Glib::ustring("paste.png"), Gtk::ALIGN_END, false);
+    initButton(*pasteNURBS, Glib::ustring("paste"), Gtk::ALIGN_END, false);
     loadNURBS = Gtk::manage (new Gtk::Button ());
-    initButton(*loadNURBS, Glib::ustring("folder-open.png"), Gtk::ALIGN_END, false);
+    initButton(*loadNURBS, Glib::ustring("folder-open"), Gtk::ALIGN_END, false);
     saveNURBS = Gtk::manage (new Gtk::Button ());
-    initButton(*saveNURBS, Glib::ustring("save.png"), Gtk::ALIGN_END, false);
+    initButton(*saveNURBS, Glib::ustring("save"), Gtk::ALIGN_END, false);
 
     NURBSbbox->attach_next_to(*editPointNURBS, sideStart, 1, 1);
     NURBSbbox->attach_next_to(*editNURBS,      sideStart, 1, 1);
@@ -273,16 +273,16 @@ DiagonalCurveEditorSubGroup::DiagonalCurveEditorSubGroup (CurveEditorGroup* prt,
     paramCurveBox->attach_next_to(*shcSelector, *paramCurve, Gtk::POS_BOTTOM, 1, 1);
 
     editParam = Gtk::manage (new Gtk::ToggleButton());
-    initButton(*editParam, Glib::ustring("crosshair-node-curve.png"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
+    initButton(*editParam, Glib::ustring("crosshair-node-curve"), Gtk::ALIGN_START, false, "EDIT_PIPETTE_TOOLTIP");
     editParam->hide();
     copyParam = Gtk::manage (new Gtk::Button ());
-    initButton(*copyParam, Glib::ustring("copy.png"), Gtk::ALIGN_END, true);
+    initButton(*copyParam, Glib::ustring("copy"), Gtk::ALIGN_END, true);
     pasteParam = Gtk::manage (new Gtk::Button ());
-    initButton(*pasteParam, Glib::ustring("paste.png"), Gtk::ALIGN_END, false);
+    initButton(*pasteParam, Glib::ustring("paste"), Gtk::ALIGN_END, false);
     loadParam = Gtk::manage (new Gtk::Button ());
-    initButton(*loadParam, Glib::ustring("folder-open.png"), Gtk::ALIGN_END, false);
+    initButton(*loadParam, Glib::ustring("folder-open"), Gtk::ALIGN_END, false);
     saveParam = Gtk::manage (new Gtk::Button ());
-    initButton(*saveParam, Glib::ustring("save.png"), Gtk::ALIGN_END, false);
+    initButton(*saveParam, Glib::ustring("save"), Gtk::ALIGN_END, false);
 
     parambbox->attach_next_to(*editParam,  sideStart, 1, 1);
     parambbox->attach_next_to(*copyParam,  sideEnd,   1, 1);
@@ -428,7 +428,6 @@ void DiagonalCurveEditorSubGroup::editModeSwitchedOff ()
     prevState = editCustomConn.block(true);
     editCustom->set_active(false);
     customCurve->pipetteMouseOver(nullptr, nullptr, 0);
-    customCurve->setDirty(true);
 
     if (!prevState) {
         editCustomConn.block(false);
@@ -437,7 +436,6 @@ void DiagonalCurveEditorSubGroup::editModeSwitchedOff ()
     prevState = editNURBSConn.block(true);
     editNURBS->set_active(false);
     NURBSCurve->pipetteMouseOver(nullptr, nullptr, 0);
-    NURBSCurve->setDirty(true);
 
     if (!prevState) {
         editNURBSConn.block(false);
@@ -446,7 +444,6 @@ void DiagonalCurveEditorSubGroup::editModeSwitchedOff ()
     prevState = editParamConn.block(true);
     editParam->set_active(false);
     paramCurve->pipetteMouseOver(nullptr, nullptr, 0);
-    paramCurve->setDirty(true);
 
     if (!prevState) {
         editParamConn.block(false);
@@ -461,12 +458,10 @@ void DiagonalCurveEditorSubGroup::pipetteMouseOver(EditDataProvider *provider, i
     case (DCT_Spline):
     case (DCT_CatumullRom):
         customCurve->pipetteMouseOver(curveEditor, provider, modifierKey);
-        customCurve->setDirty(true);
         break;
 
     case (DCT_Parametric): {
         paramCurve->pipetteMouseOver(curveEditor, provider, modifierKey);
-        paramCurve->setDirty(true);
         float pipetteVal = 0.f;
         editedAdjuster = nullptr;
         int n = 0;
@@ -517,7 +512,6 @@ void DiagonalCurveEditorSubGroup::pipetteMouseOver(EditDataProvider *provider, i
 
     case (DCT_NURBS):
         NURBSCurve->pipetteMouseOver(curveEditor, provider, modifierKey);
-        NURBSCurve->setDirty(true);
         break;
 
     default:    // (DCT_Linear, DCT_Unchanged)
@@ -753,7 +747,6 @@ void DiagonalCurveEditorSubGroup::switchGUI()
                 dCurve->paramCurveEd.at(3)
             );
 
-            double s = (double)RTScalable::getScale();
             highlights->setValue (dCurve->paramCurveEd.at(4));
             highlights->setLabel(label[3]);
             lights->setValue (dCurve->paramCurveEd.at(5));
@@ -765,8 +758,8 @@ void DiagonalCurveEditorSubGroup::switchGUI()
             shcSelector->coloredBar.setColorProvider(barColorProvider, dCurve->getBottomBarCallerId());
             shcSelector->coloredBar.setBgGradient(bgGradient);
             shcSelector->setMargins(
-                    (int)( ((leftBar ? (double)CBAR_WIDTH + 2. + (double)CBAR_MARGIN + RADIUS : RADIUS) - 1.5) * s ),
-                    (int)((RADIUS - 1.5) * s)
+                    (int)( (leftBar ? (double)CBAR_WIDTH + 2. + (double)CBAR_MARGIN + RADIUS : RADIUS) - 1.5 ),
+                    (int)( RADIUS - 1.5 )
                     );
             paramCurve->setColoredBar(leftBar, nullptr);
             paramCurve->queue_resize_no_redraw();
@@ -895,11 +888,9 @@ void DiagonalCurveEditorSubGroup::loadPressed ()
 
             if (p[0] == (double)(DCT_Spline) || p[0] == (double)(DCT_CatumullRom)) {
                 customCurve->setPoints (p);
-                customCurve->queue_draw ();
                 customCurve->notifyListener ();
             } else if (p[0] == (double)(DCT_NURBS)) {
                 NURBSCurve->setPoints (p);
-                NURBSCurve->queue_draw ();
                 NURBSCurve->notifyListener ();
             } else if (p[0] == (double)(DCT_Parametric)) {
                 shcSelector->setPositions ( p[1], p[2], p[3] );
@@ -908,7 +899,6 @@ void DiagonalCurveEditorSubGroup::loadPressed ()
                 darks->setValue (p[6]);
                 shadows->setValue (p[7]);
                 paramCurve->setPoints (p);
-                paramCurve->queue_draw ();
                 paramCurve->notifyListener ();
             }
         }
@@ -966,7 +956,6 @@ void DiagonalCurveEditorSubGroup::pastePressed ()
         case DCT_Spline:           // custom
         case DCT_CatumullRom:
             customCurve->setPoints (curve);
-            customCurve->queue_draw ();
             customCurve->notifyListener ();
             break;
 
@@ -981,13 +970,11 @@ void DiagonalCurveEditorSubGroup::pastePressed ()
             darks->setValue (curve[6]);
             shadows->setValue (curve[7]);
             paramCurve->setPoints (curve);
-            paramCurve->queue_draw ();
             paramCurve->notifyListener ();
             break;
 
         case DCT_NURBS:            // NURBS
             NURBSCurve->setPoints (curve);
-            NURBSCurve->queue_draw ();
             NURBSCurve->notifyListener ();
             break;
 
