@@ -23,6 +23,7 @@
 #include "../rtengine/utils.h"
 #include "../rtengine/procparams.h"
 #include "rtimage.h"
+#include "rtscalable.h"
 #include "multilangmgr.h"
 
 #include <assert.h>
@@ -31,12 +32,6 @@
 
 using namespace std;
 
-Glib::RefPtr<RTImage> MyExpander::inconsistentImage;
-Glib::RefPtr<RTImage> MyExpander::enabledImage;
-Glib::RefPtr<RTImage> MyExpander::disabledImage;
-Glib::RefPtr<RTImage> MyExpander::openedImage;
-Glib::RefPtr<RTImage> MyExpander::closedImage;
-
 IdleRegister::~IdleRegister()
 {
     destroy();
@@ -131,13 +126,14 @@ Gtk::Border getPadding(const Glib::RefPtr<Gtk::StyleContext> style)
         return padding;
     }
 
-    int s = (double)RTScalable::getScale();
     padding = style->get_padding();
-    if (s > 1) {
-        padding.set_left(padding.get_left() * s);
-        padding.set_right(padding.get_right() * s);
-        padding.set_top(padding.get_top() * s);
-        padding.set_bottom(padding.get_bottom() * s);
+
+    if (RTScalable::getGlobalScale() > 1.0) {
+        // Scale pixel border size based on DPI and Scale
+        padding.set_left(RTScalable::scalePixelSize(padding.get_left()));
+        padding.set_right(RTScalable::scalePixelSize(padding.get_right()));
+        padding.set_top(RTScalable::scalePixelSize(padding.get_top()));
+        padding.set_bottom(RTScalable::scalePixelSize(padding.get_bottom()));
     }
 
     return padding;
@@ -536,27 +532,12 @@ void ExpanderBox::hideBox()
     Gtk::EventBox::hide();
 }
 
-void MyExpander::init()
-{
-    if (!inconsistentImage) {  // if one is null, all are null
-        inconsistentImage = Glib::RefPtr<RTImage>(new RTImage("power-inconsistent-small.png"));
-        enabledImage = Glib::RefPtr<RTImage>(new RTImage("power-on-small.png"));
-        disabledImage = Glib::RefPtr<RTImage>(new RTImage("power-off-small.png"));
-        openedImage = Glib::RefPtr<RTImage>(new RTImage("expander-open-small.png"));
-        closedImage = Glib::RefPtr<RTImage>(new RTImage("expander-closed-small.png"));
-    }
-}
-
-void MyExpander::cleanup()
-{
-    inconsistentImage.reset();
-    enabledImage.reset();
-    disabledImage.reset();
-    openedImage.reset();
-    closedImage.reset();
-}
-
 MyExpander::MyExpander(bool useEnabled, Gtk::Widget* titleWidget) :
+    inconsistentImage("power-inconsistent-small"),
+    enabledImage("power-on-small"),
+    disabledImage("power-off-small"),
+    openedImage("expander-open-small"),
+    closedImage("expander-closed-small"),
     enabled(false), inconsistent(false), flushEvent(false), expBox(nullptr),
     child(nullptr), headerWidget(nullptr), statusImage(nullptr),
     label(nullptr), useEnabled(useEnabled)
@@ -613,6 +594,11 @@ MyExpander::MyExpander(bool useEnabled, Gtk::Widget* titleWidget) :
 }
 
 MyExpander::MyExpander(bool useEnabled, Glib::ustring titleLabel) :
+    inconsistentImage("power-inconsistent-small"),
+    enabledImage("power-on-small"),
+    disabledImage("power-off-small"),
+    openedImage("expander-open-small"),
+    closedImage("expander-closed-small"),
     enabled(false), inconsistent(false), flushEvent(false), expBox(nullptr),
     child(nullptr), headerWidget(nullptr),
     label(nullptr), useEnabled(useEnabled)
@@ -754,13 +740,13 @@ void MyExpander::set_inconsistent(bool isInconsistent)
 
         if (useEnabled) {
             if (isInconsistent) {
-                statusImage->set(inconsistentImage->get_surface());
+                statusImage->set_from_icon_name(inconsistentImage);
             } else {
                 if (enabled) {
-                    statusImage->set(enabledImage->get_surface());
+                    statusImage->set_from_icon_name(enabledImage);
                     get_style_context()->add_class("enabledTool");
                 } else {
-                    statusImage->set(disabledImage->get_surface());
+                    statusImage->set_from_icon_name(disabledImage);
                     get_style_context()->remove_class("enabledTool");
                 }
             }
@@ -787,7 +773,7 @@ void MyExpander::setEnabled(bool isEnabled)
                 enabled = false;
 
                 if (!inconsistent) {
-                    statusImage->set(disabledImage->get_surface());
+                    statusImage->set_from_icon_name(disabledImage);
                     get_style_context()->remove_class("enabledTool");
                     message.emit();
                 }
@@ -795,7 +781,7 @@ void MyExpander::setEnabled(bool isEnabled)
                 enabled = true;
 
                 if (!inconsistent) {
-                    statusImage->set(enabledImage->get_surface());
+                    statusImage->set_from_icon_name(enabledImage);
                     get_style_context()->add_class("enabledTool");
                     message.emit();
                 }
@@ -826,9 +812,9 @@ void MyExpander::set_expanded( bool expanded )
 
     if (!useEnabled) {
         if (expanded ) {
-            statusImage->set(openedImage->get_surface());
+            statusImage->set_from_icon_name(openedImage);
         } else {
-            statusImage->set(closedImage->get_surface());
+            statusImage->set_from_icon_name(closedImage);
         }
     }
 
@@ -871,9 +857,9 @@ bool MyExpander::on_toggle(GdkEventButton* event)
 
     if (!useEnabled) {
         if (isVisible) {
-            statusImage->set(closedImage->get_surface());
+            statusImage->set_from_icon_name(closedImage);
         } else {
-            statusImage->set(openedImage->get_surface());
+            statusImage->set_from_icon_name(openedImage);
         }
     }
 
@@ -898,11 +884,11 @@ bool MyExpander::on_enabled_change(GdkEventButton* event)
     if (event->button == 1) {
         if (enabled) {
             enabled = false;
-            statusImage->set(disabledImage->get_surface());
+            statusImage->set_from_icon_name(disabledImage);
             get_style_context()->remove_class("enabledTool");
         } else {
             enabled = true;
-            statusImage->set(enabledImage->get_surface());
+            statusImage->set_from_icon_name(enabledImage);
             get_style_context()->add_class("enabledTool");
         }
 
@@ -966,17 +952,17 @@ bool MyScrolledWindow::on_scroll_event (GdkEventScroll* event)
 
 void MyScrolledWindow::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    natural_width = minimum_width = 100 * RTScalable::getScale();
+    natural_width = minimum_width = RTScalable::scalePixelSize(100);
 }
 
 void MyScrolledWindow::get_preferred_height_vfunc (int &minimum_height, int &natural_height) const
 {
-    natural_height = minimum_height = 50 * RTScalable::getScale();
+    natural_height = minimum_height = RTScalable::scalePixelSize(50);
 }
 
 void MyScrolledWindow::get_preferred_height_for_width_vfunc (int width, int &minimum_height, int &natural_height) const
 {
-    natural_height = minimum_height = 50 * RTScalable::getScale();
+    natural_height = minimum_height = RTScalable::scalePixelSize(50);
 }
 
 /*
@@ -1055,7 +1041,7 @@ void MyScrolledToolbar::get_preferred_height_vfunc (int &minimumHeight, int &nat
 
 MyComboBoxText::MyComboBoxText (bool has_entry) : Gtk::ComboBoxText(has_entry)
 {
-    minimumWidth = naturalWidth = 70;
+    minimumWidth = naturalWidth = RTScalable::scalePixelSize(70);
     Gtk::CellRendererText* cellRenderer = dynamic_cast<Gtk::CellRendererText*>(get_first_cell());
     cellRenderer->property_ellipsize() = Pango::ELLIPSIZE_MIDDLE;
     add_events(Gdk::SCROLL_MASK|Gdk::SMOOTH_SCROLL_MASK);
@@ -1079,12 +1065,12 @@ bool MyComboBoxText::on_scroll_event (GdkEventScroll* event)
 void MyComboBoxText::setPreferredWidth (int minimum_width, int natural_width)
 {
     if (natural_width == -1 && minimum_width == -1) {
-        naturalWidth = minimumWidth = 70 * RTScalable::getScale();
+        naturalWidth = minimumWidth = RTScalable::scalePixelSize(70);
     } else if (natural_width == -1) {
         naturalWidth =  minimumWidth = minimum_width;
     } else if (minimum_width == -1) {
         naturalWidth = natural_width;
-        minimumWidth = rtengine::max(naturalWidth / 2, 20);
+        minimumWidth = rtengine::max(naturalWidth / 2, RTScalable::scalePixelSize(20));
         minimumWidth = rtengine::min(naturalWidth, minimumWidth);
     } else {
         naturalWidth = natural_width;
@@ -1094,19 +1080,20 @@ void MyComboBoxText::setPreferredWidth (int minimum_width, int natural_width)
 
 void MyComboBoxText::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    natural_width = rtengine::max(naturalWidth, 10 * RTScalable::getScale());
-    minimum_width = rtengine::max(minimumWidth, 10 * RTScalable::getScale());
+    natural_width = rtengine::max(naturalWidth, RTScalable::scalePixelSize(10));
+    minimum_width = rtengine::max(minimumWidth, RTScalable::scalePixelSize(10));
 }
+
 void MyComboBoxText::get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const
 {
-    natural_width = rtengine::max(naturalWidth, 10 * RTScalable::getScale());
-    minimum_width = rtengine::max(minimumWidth, 10 * RTScalable::getScale());
+    natural_width = rtengine::max(naturalWidth, RTScalable::scalePixelSize(10));
+    minimum_width = rtengine::max(minimumWidth, RTScalable::scalePixelSize(10));
 }
 
 
 MyComboBox::MyComboBox ()
 {
-    minimumWidth = naturalWidth = 70 * RTScalable::getScale();
+    minimumWidth = naturalWidth = RTScalable::scalePixelSize(70);
 }
 
 bool MyComboBox::on_scroll_event (GdkEventScroll* event)
@@ -1125,12 +1112,12 @@ bool MyComboBox::on_scroll_event (GdkEventScroll* event)
 void MyComboBox::setPreferredWidth (int minimum_width, int natural_width)
 {
     if (natural_width == -1 && minimum_width == -1) {
-        naturalWidth = minimumWidth = 70 * RTScalable::getScale();
+        naturalWidth = minimumWidth = RTScalable::scalePixelSize(70);
     } else if (natural_width == -1) {
         naturalWidth =  minimumWidth = minimum_width;
     } else if (minimum_width == -1) {
         naturalWidth = natural_width;
-        minimumWidth = rtengine::max(naturalWidth / 2, 20);
+        minimumWidth = rtengine::max(naturalWidth / 2, RTScalable::scalePixelSize(20));
         minimumWidth = rtengine::min(naturalWidth, minimumWidth);
     } else {
         naturalWidth = natural_width;
@@ -1140,13 +1127,14 @@ void MyComboBox::setPreferredWidth (int minimum_width, int natural_width)
 
 void MyComboBox::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    natural_width = rtengine::max(naturalWidth, 10 * RTScalable::getScale());
-    minimum_width = rtengine::max(minimumWidth, 10 * RTScalable::getScale());
+    natural_width = rtengine::max(naturalWidth, RTScalable::scalePixelSize(10));
+    minimum_width = rtengine::max(minimumWidth, RTScalable::scalePixelSize(10));
 }
+
 void MyComboBox::get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const
 {
-    natural_width = rtengine::max(naturalWidth, 10 * RTScalable::getScale());
-    minimum_width = rtengine::max(minimumWidth, 10 * RTScalable::getScale());
+    natural_width = rtengine::max(naturalWidth, RTScalable::scalePixelSize(10));
+    minimum_width = rtengine::max(minimumWidth, RTScalable::scalePixelSize(10));
 }
 
 MySpinButton::MySpinButton ()
@@ -1275,7 +1263,7 @@ MyFileChooserWidget::MyFileChooserWidget(const Glib::ustring &title, Gtk::FileCh
 
 std::unique_ptr<Gtk::Image> MyFileChooserWidget::make_folder_image()
 {
-    return std::unique_ptr<Gtk::Image>(new RTImage("folder-open-small.png"));
+    return std::unique_ptr<Gtk::Image>(new RTImage("folder-open-small", Gtk::ICON_SIZE_BUTTON));
 }
 
 void MyFileChooserWidget::show_chooser(Gtk::Widget *parent)
@@ -1475,11 +1463,12 @@ bool MyFileChooserButton::on_scroll_event (GdkEventScroll* event)
 
 void MyFileChooserButton::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    minimum_width = natural_width = 35 * RTScalable::getScale();
+    minimum_width = natural_width = RTScalable::scalePixelSize(35);
 }
+
 void MyFileChooserButton::get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const
 {
-    minimum_width = natural_width = 35 * RTScalable::getScale();
+    minimum_width = natural_width = RTScalable::scalePixelSize(35);
 }
 
 
@@ -1535,10 +1524,10 @@ void MyFileChooserEntry::on_filename_set()
 }
 
 
-TextOrIcon::TextOrIcon (const Glib::ustring &fname, const Glib::ustring &labelTx, const Glib::ustring &tooltipTx)
+TextOrIcon::TextOrIcon (const Glib::ustring &icon_name, const Glib::ustring &labelTx, const Glib::ustring &tooltipTx)
 {
 
-    RTImage *img = Gtk::manage(new RTImage(fname));
+    RTImage *img = Gtk::manage(new RTImage(icon_name, Gtk::ICON_SIZE_LARGE_TOOLBAR));
     pack_start(*img, Gtk::PACK_SHRINK, 0);
     set_tooltip_markup("<span font_size=\"large\" font_weight=\"bold\">" + labelTx  + "</span>\n" + tooltipTx);
 
@@ -1554,19 +1543,19 @@ public:
     Gtk::Label* label;
 
     Impl(RTImage* image, Gtk::Label* label) : image(image), label(label) {}
-    static std::unique_ptr<RTImage> createImage(const Glib::ustring& fileName);
+    static std::unique_ptr<RTImage> createImage(const Glib::ustring& iconName);
 };
 
-std::unique_ptr<RTImage> ImageAndLabel::Impl::createImage(const Glib::ustring& fileName)
+std::unique_ptr<RTImage> ImageAndLabel::Impl::createImage(const Glib::ustring& iconName)
 {
-    if (fileName.empty()) {
+    if (iconName.empty()) {
         return nullptr;
     }
-    return std::unique_ptr<RTImage>(new RTImage(fileName));
+    return std::unique_ptr<RTImage>(new RTImage(iconName, Gtk::ICON_SIZE_LARGE_TOOLBAR));
 }
 
-ImageAndLabel::ImageAndLabel(const Glib::ustring& label, const Glib::ustring& imageFileName) :
-    ImageAndLabel(label, Gtk::manage(Impl::createImage(imageFileName).release()))
+ImageAndLabel::ImageAndLabel(const Glib::ustring& label, const Glib::ustring& iconName) :
+    ImageAndLabel(label, Gtk::manage(Impl::createImage(iconName).release()))
 {
 }
 
@@ -1602,15 +1591,15 @@ private:
     std::unique_ptr<ImageAndLabel> widget;
 
 public:
-    Impl(const Glib::ustring &label, const Glib::ustring &imageFileName) :
-        widget(new ImageAndLabel(label, imageFileName)) {}
+    Impl(const Glib::ustring &label, const Glib::ustring &iconName) :
+        widget(new ImageAndLabel(label, iconName)) {}
     Impl(const Glib::ustring &label, RTImage *itemImage) :
         widget(new ImageAndLabel(label, itemImage)) {}
     ImageAndLabel* getWidget() const { return widget.get(); }
 };
 
-MyImageMenuItem::MyImageMenuItem(const Glib::ustring& label, const Glib::ustring& imageFileName) :
-    pimpl(new Impl(label, imageFileName))
+MyImageMenuItem::MyImageMenuItem(const Glib::ustring& label, const Glib::ustring& iconName) :
+    pimpl(new Impl(label, iconName))
 {
     add(*(pimpl->getWidget()));
 }
@@ -1653,18 +1642,18 @@ const Gtk::Label* MyRadioImageMenuItem::getLabel() const
     return pimpl->getWidget()->getLabel();
 }
 
-MyProgressBar::MyProgressBar(int width) : w(rtengine::max(width, 10 * RTScalable::getScale())) {}
-MyProgressBar::MyProgressBar() : w(200 * RTScalable::getScale()) {}
+MyProgressBar::MyProgressBar(int width) : w(rtengine::max(width, RTScalable::scalePixelSize(10))) {}
+MyProgressBar::MyProgressBar() : w(RTScalable::scalePixelSize(200)) {}
 
 void MyProgressBar::setPreferredWidth(int width)
 {
-    w = rtengine::max(width, 10 * RTScalable::getScale());
+    w = rtengine::max(width, RTScalable::scalePixelSize(10));
 }
 
 void MyProgressBar::get_preferred_width_vfunc (int &minimum_width, int &natural_width) const
 {
-    minimum_width = rtengine::max(w / 2, 50 * RTScalable::getScale());
-    natural_width = rtengine::max(w, 50 * RTScalable::getScale());
+    minimum_width = rtengine::max(w / 2, RTScalable::scalePixelSize(50));
+    natural_width = rtengine::max(w, RTScalable::scalePixelSize(50));
 }
 
 void MyProgressBar::get_preferred_width_for_height_vfunc (int height, int &minimum_width, int &natural_width) const
@@ -2031,7 +2020,7 @@ Gtk::ToggleButton SpotPicker::spotButtonTemplate(Glib::ustring const &key, const
     setExpandAlignProperties(&spotButton, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
     spotButton.get_style_context()->add_class("independent");
     spotButton.set_tooltip_text(tooltip);
-    spotButton.set_image(*Gtk::manage(new RTImage("color-picker-small.png")));
+    spotButton.set_image_from_icon_name("color-picker-small");
     return spotButton;
 }
 
@@ -2039,3 +2028,42 @@ void SpotPicker::spotSizeChanged()
 {
     _spotHalfWidth = atoi(_spotSizeSetter.get_active_text().c_str());
 }
+
+// OptionalRadioButtonGroup class
+
+void OptionalRadioButtonGroup::onButtonToggled(Gtk::ToggleButton *button)
+{
+    if (!button) {
+        return;
+    }
+
+    if (button->get_active()) {
+        if (active_button == button) {
+            // Same button, noting to do.
+        } else if (active_button) {
+            // Deactivate the other button.
+            active_button->set_active(false);
+        }
+        active_button = button;
+    } else {
+        if (active_button == button) {
+            // Active button got deactivated.
+            active_button = nullptr;
+        } else {
+            // No effect on other buttons.
+        }
+    }
+}
+
+Gtk::ToggleButton *OptionalRadioButtonGroup::getActiveButton() const
+{
+    return active_button;
+}
+
+void OptionalRadioButtonGroup::register_button(Gtk::ToggleButton &button)
+{
+    button.signal_toggled().connect(sigc::bind(
+        sigc::mem_fun(this, &OptionalRadioButtonGroup::onButtonToggled),
+        &button));
+    onButtonToggled(&button);
+}
