@@ -49,10 +49,13 @@ protected:
     Gtk::Frame* dcpFrame;
     Gtk::Frame* coipFrame;
     Gtk::Frame* redFrame;
+    Gtk::Frame* colorFramecie;    
     MyExpander* trcExp;
 
     Adjuster* wGamma;
     Adjuster* wSlope;
+    Adjuster* wmidtcie;
+    Gtk::CheckButton* wsmoothcie;
     Adjuster* redx;
     Adjuster* redy;
     Adjuster* grex;
@@ -60,13 +63,19 @@ protected:
     Adjuster* blux;
     Adjuster* bluy;
     Adjuster* preser;
-
+    Adjuster* refi;
+    Adjuster* shiftx;
+    Adjuster* shifty;
+    sigc::connection wsmoothcieconn;
+    bool lastwsmoothcie;
     Gtk::Label* labmga;
     Gtk::Box* gabox;
     //Gtk::Label* blr;
     //Gtk::Label* blg;
     //Gtk::Label* blb;
     Gtk::Button* neutral;
+    sigc::connection trcExpconn;
+    bool lasttrcExp;
 
     sigc::connection neutralconn;
     bool lastToneCurve;
@@ -111,6 +120,13 @@ private:
     rtengine::ProcEvent EvICMLabGridciexy;
     rtengine::ProcEvent EvICMfbw;
     rtengine::ProcEvent EvICMgamut;
+    rtengine::ProcEvent EvICMcat;
+    rtengine::ProcEvent EvICMrefi;
+    rtengine::ProcEvent EvICMtrcExp;
+    rtengine::ProcEvent EvICMshiftx;
+    rtengine::ProcEvent EvICMshifty;
+    rtengine::ProcEvent EvICMwmidtcie;
+    rtengine::ProcEvent EvICMwsmoothcie;
     LabGrid *labgridcie;
     IdleRegister idle_register;
 
@@ -127,6 +143,10 @@ private:
     Gtk::CheckButton* fbw;
     Gtk::CheckButton* gamut;
 
+    Gtk::Box* wcatBox;
+    Gtk::Label* wcatlab;
+
+
     Gtk::CheckButton* obpc;
     Gtk::RadioButton* inone;
 
@@ -149,6 +169,9 @@ private:
     sigc::connection willconn;
     MyComboBoxText* wprim;
     sigc::connection wprimconn;
+    MyComboBoxText* wcat;
+    sigc::connection wcatconn;
+    
     std::unique_ptr<PopUpButton> aRendIntent;
     sigc::connection arendintentconn;
 
@@ -167,6 +190,7 @@ private:
     double dcpTemperatures[2];
     Glib::ustring lastRefFilename;
     Glib::ustring camName;
+    Glib::ustring filename;
     void updateDCP(int dcpIlluminant, Glib::ustring dcp_name);
     void updateRenderingIntent(const Glib::ustring &profile);
     void foldAllButMe (GdkEventButton* event, MyExpander *expander);
@@ -179,6 +203,8 @@ private:
     float nextgy;
     float nextwx;
     float nextwy;
+    float nextmx;
+    float nextmy;
 
 public:
     static const Glib::ustring TOOL_NAME;
@@ -192,18 +218,22 @@ public:
     void setDefaults(const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr) override;
     void adjusterChanged(Adjuster* a, double newval) override;
     void primChanged (float rx, float ry, float bx, float by, float gx, float gy) override;
-    void iprimChanged (float r_x, float r_y, float b_x, float b_y, float g_x, float g_y, float w_x, float w_y) override;
+    void iprimChanged (float r_x, float r_y, float b_x, float b_y, float g_x, float g_y, float w_x, float w_y, float m_x, float m_y) override;
     void neutral_pressed();
 
     void wpChanged();
     void wtrcinChanged();
     void willChanged();
     void wprimChanged();
+    void wcatChanged();
+    void trcExpChanged();
     void opChanged();
     void oiChanged(int n);
     void aiChanged(int n);
     void oBPCChanged();
     void fbwChanged();
+    void wsmoothcieChanged();
+    
     void gamutChanged();
     void ipChanged();
     void ipSelectionChanged();
