@@ -34,7 +34,7 @@
 
 class ImageAreaPanel;
 
-class ImageArea :
+class ImageArea final :
     public Gtk::DrawingArea,
     public CropWindowListener,
     public EditDataProvider,
@@ -148,6 +148,8 @@ public:
     void subscribe(EditSubscriber *subscriber) override;
     void unsubscribe() override;
     void getImageSize (int &w, int&h) override;
+    void getPreviewCenterPos(int &x, int &y) override;
+    void getPreviewSize(int &w, int &h) override;
 
     // CropWindowListener interface
     void cropPositionChanged   (CropWindow* cw) override;
