@@ -53,10 +53,13 @@ void LockableColorPicker::updateBackBuffer ()
         Gtk::DrawingArea *iArea = cropWindow->getImageArea();
 
         Glib::RefPtr<Pango::Context> pangoContext = iArea->get_pango_context ();
-        Pango::FontDescription fontd = pangoContext->get_font_description();
+        Pango::FontDescription fontd = iArea->get_style_context()->get_font();
         // set font family and size
         fontd.set_family(options.CPFontFamily == "default" ? "sans" : options.CPFontFamily);
-        fontd.set_size((options.CPFontFamily == "default" ? 8 : options.CPFontSize) * Pango::SCALE);
+        const int fontSize = options.CPFontFamily == "default" ? 8 : options.CPFontSize; // pt
+        // Non-absolute size is defined in "Pango units" and shall be multiplied by
+        // Pango::SCALE from "pt":
+        fontd.set_size (fontSize * Pango::SCALE);
         fontd.set_weight(Pango::WEIGHT_NORMAL);
         pangoContext->set_font_description (fontd);
 
