@@ -24,6 +24,25 @@
 
 #include <glibmm/ustring.h>
 
+class TranslationMetadata
+{
+public:
+    TranslationMetadata() = default;
+    ~TranslationMetadata() = default;
+    TranslationMetadata(const TranslationMetadata &other) = delete;
+    TranslationMetadata(TranslationMetadata &&other) = delete;
+    explicit TranslationMetadata(std::map<std::string, std::string> &&metadata);
+
+    TranslationMetadata &operator =(const TranslationMetadata &other) = delete;
+    TranslationMetadata &operator =(TranslationMetadata &&other) noexcept = default;
+
+    std::string get(const std::string &key, const std::string &default_value) const;
+    std::string getLanguageName(const std::string &default_name) const;
+
+private:
+    std::map<std::string, std::string> metadata;
+};
+
 class MultiLangMgr
 {
 public:
@@ -31,11 +50,13 @@ public:
 
     void load(const Glib::ustring &language, const std::vector<Glib::ustring> &fnames);
     Glib::ustring getStr(const std::string& key) const;
+    const TranslationMetadata *getMetadata(const Glib::ustring &fname) const;
     static bool isOSLanguageDetectSupported();
     static Glib::ustring getOSUserLanguage();
 
 private:
     std::map<std::string, Glib::ustring> translations;
+    mutable std::map<Glib::ustring, TranslationMetadata> lang_files_metadata;
 };
 
 extern MultiLangMgr langMgr;
