@@ -371,7 +371,7 @@ struct SHParamsEdited {
 
 struct ToneEqualizerParamsEdited {
     bool enabled;
-    std::array<bool, 5> bands;
+    std::array<bool, 6> bands;
     bool regularization;
     bool show_colormap;
     bool pivot;
@@ -476,6 +476,7 @@ public:
         bool strcolab;
         bool strcolh;
         bool angcol;
+        bool feathercol;
         bool blurcolde;
         bool blurcol;
         bool contcol;
@@ -538,6 +539,7 @@ public:
         bool blurexpde;
         bool strexp;
         bool angexp;
+        bool featherexp;
         bool excurve;
         bool norm;
         bool inversex;
@@ -577,7 +579,7 @@ public:
         bool expshadhigh;
         bool complexshadhigh;
         bool shMethod;
-        bool multsh[6];
+        bool multsh[7];
         bool highlights;
         bool h_tonalwidth;
         bool shadows;
@@ -593,6 +595,7 @@ public:
         bool blurSHde;
         bool strSH;
         bool angSH;
+        bool featherSH;
         bool inverssh;
         bool chromaskSH;
         bool gammaskSH;
@@ -638,6 +641,7 @@ public:
         bool strvibab;
         bool strvibh;
         bool angvib;
+        bool feathervib;
         bool Lmaskvibcurve;
         bool recothresv;
         bool lowthresv;
@@ -779,6 +783,7 @@ public:
         bool equilret;
         bool loglin;
         bool dehazeSaturation;
+        bool dehazeblack;
         bool softradiusret;
         bool CCmaskreticurve;
         bool LLmaskreticurve;
@@ -853,6 +858,7 @@ public:
         bool sigmalc2;
         bool strwav;
         bool angwav;
+        bool featherwav;
         bool strengthw;
         bool sigmaed;
         bool radiusw;
@@ -945,8 +951,13 @@ public:
         bool fullimage;
         bool repar;
         bool ciecam;
+        bool satlog;
         bool blackEv;
         bool whiteEv;
+        bool whiteslog;
+        bool blackslog;
+        bool comprlog;
+        bool strelog;
         bool detail;
         bool sursour;
         bool surround;
@@ -954,6 +965,7 @@ public:
         bool baselog;
         bool strlog;
         bool anglog;
+        bool featherlog;
         bool CCmaskcurveL;
         bool LLmaskcurveL;
         bool HHmaskcurveL;
@@ -991,6 +1003,7 @@ public:
         bool shadmask;
         bool str_mask;
         bool ang_mask;
+        bool feather_mask;
         bool HHhmask_curve;
         bool Lmask_curve;
         bool LLmask_curvewav;
@@ -999,6 +1012,7 @@ public:
         bool visicie;
         bool complexcie;
         bool expcie;
+        bool expprecam;
         bool reparcie;
         bool sensicie;
         bool Autograycie;
@@ -1006,8 +1020,17 @@ public:
         bool forcebw;
         bool qtoj;
         bool jabcie;
-        bool sigmoidqjcie;
+        bool comprcieauto;
+        bool normcie;
+        bool gamutcie;
+        bool bwcie;
+        bool sigcie;
         bool logcie;
+        bool satcie;
+        bool logcieq;
+        bool smoothcie;
+        bool smoothcieyb;
+        bool smoothcielum;
         bool logjz;
         bool sigjz;
         bool sigq;
@@ -1016,6 +1039,7 @@ public:
         bool sourceabscie;
         bool sursourcie;
         bool modecam;
+        bool bwevMethod;
         bool modecie;
         bool saturlcie;
         bool rstprotectcie;
@@ -1040,8 +1064,10 @@ public:
         bool lightlcie;
         bool lightjzcie;
         bool lightqcie;
+        bool lightsigqcie;
         bool contlcie;
         bool contjzcie;
+        bool detailciejz;
         bool adapjzcie;
         bool jz100;
         bool pqremap;
@@ -1057,31 +1083,65 @@ public:
         bool targetjz;
         bool sigmoidldacie;
         bool sigmoidthcie;
+        bool sigmoidsenscie;
         bool sigmoidblcie;
+        bool comprcie;
+        bool strcielog;
+        bool comprcieth;
+        bool gamjcie;
+        bool slopjcie;
+        bool slopesmo;
+        bool slopesmor;
+        bool slopesmog;
+        bool slopesmob;
+        bool midtcie;
+        bool redxl;
+        bool redyl;
+        bool grexl;
+        bool greyl;
+        bool bluxl;
+        bool bluyl;
+        bool refi;
+        bool shiftxl;
+        bool shiftyl;
+        bool labgridcieALow;
+        bool labgridcieBLow;
+        bool labgridcieAHigh;
+        bool labgridcieBHigh;
+        bool labgridcieGx;
+        bool labgridcieGy;
+        bool labgridcieWx;
+        bool labgridcieWy;       
+        bool labgridcieMx;
+        bool labgridcieMy;       
+        bool whitescie;
+        bool blackscie;
+        bool illMethod;
+        bool smoothciemet;
+        bool primMethod;
+        bool catMethod;
         bool sigmoidldajzcie;
         bool sigmoidthjzcie;
         bool sigmoidbljzcie;
         bool contqcie;
+        bool contsigqcie;
         bool colorflcie;
-/*
-        bool lightlzcam;
-        bool lightqzcam;
-        bool contlzcam;
-        bool contqzcam; 
-        bool contthreszcam;
-        bool colorflzcam;
-        bool saturzcam;
-        bool chromzcam;
-*/
+
         bool targabscie;
         bool targetGraycie;
         bool catadcie;
         bool detailcie;
         bool surroundcie;
+        bool strgradcie;
+        bool anggradcie;
+        bool feathercie;
+
         bool enacieMask;
+        bool enacieMaskall;
         bool CCmaskciecurve;
         bool LLmaskciecurve;
         bool HHmaskciecurve;
+        bool HHhmaskciecurve;
         bool blendmaskcie;
         bool radmaskcie;
         bool sigmalcjz;
@@ -1099,7 +1159,16 @@ public:
         bool lowthrescie;
         bool higthrescie;
         bool decaycie;
-
+        bool strumaskcie;
+        bool toolcie;
+		bool fftcieMask;
+		bool contcie;
+		bool blurcie;
+        bool highmaskcie;
+        bool shadmaskcie;
+        bool LLmaskciecurvewav;
+        bool csthresholdcie;
+		
         LocallabSpotEdited(bool v);
 
         void set(bool v);
@@ -1241,16 +1310,23 @@ struct ColorManagementParamsEdited {
     bool workingTRC;
     bool workingTRCGamma;
     bool workingTRCSlope;
+    bool wmidtcie;
+    bool wsmoothcie;
     bool will;
     bool wprim;
+    bool wcat;
     bool redx;
     bool redy;
     bool grex;
     bool grey;
     bool blux;
     bool bluy;
+    bool refi;
+    bool shiftx;
+    bool shifty;
     bool preser;
     bool fbw;
+    bool trcExp;
     bool gamut;
     bool labgridcieALow;
     bool labgridcieBLow;
@@ -1260,6 +1336,8 @@ struct ColorManagementParamsEdited {
     bool labgridcieGy;
     bool labgridcieWx;
     bool labgridcieWy;
+    bool labgridcieMx;
+    bool labgridcieMy;
     bool aRendIntent;
     bool outputProfile;
     bool outputIntent;
