@@ -20,10 +20,15 @@
 
 #include <set>
 
-#include <glibmm/ustring.h>
-
 #include "../rtengine/noncopyable.h"
 
+namespace Glib
+{
+
+class ustring;
+
+}
+
 class FileBrowserEntry;
 
 class PreviewLoaderListener
