@@ -62,8 +62,8 @@ private:
     Glib::ustring storedValue;
     Glib::ustring lastFilename;
     Glib::ustring imagePath;
-    RTImage *profileFillModeOnImage;
-    RTImage *profileFillModeOffImage;
+    const Glib::ustring modeOn, modeOff;
+    RTImage* const profileFillImage;
     Gtk::ToggleButton* fillMode;
     Gtk::TreeIter currRow;
     ProfileStoreEntry *lastSavedPSE;
