@@ -71,7 +71,7 @@ SaveFormatPanel::SaveFormatPanel () : listener (nullptr)
     jpegOpts->set_row_spacing(5);
     setExpandAlignProperties(jpegOpts, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
 
-    jpegQual = new Adjuster (M("SAVEDLG_JPEGQUAL"), 0, 100, 1, 100);
+    jpegQual = Gtk::manage (new Adjuster (M("SAVEDLG_JPEGQUAL"), 0, 100, 1, 100) );
     setExpandAlignProperties(jpegQual, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
     jpegQual->setAdjusterListener (this);
 
@@ -95,11 +95,16 @@ SaveFormatPanel::SaveFormatPanel () : listener (nullptr)
     // ---------------------  TIFF OPTIONS
 
 
-    tiffUncompressed = new Gtk::CheckButton (M("SAVEDLG_TIFFUNCOMPRESSED"));
+    tiffUncompressed = Gtk::manage (new Gtk::CheckButton (M("SAVEDLG_TIFFUNCOMPRESSED")) );
     setExpandAlignProperties(tiffUncompressed, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
     tiffUncompressed->signal_toggled().connect( sigc::mem_fun(*this, &SaveFormatPanel::formatChanged));
     tiffUncompressed->show_all();
 
+    bigTiff = Gtk::manage (new Gtk::CheckButton (M("SAVEDLG_BIGTIFF")) );
+    setExpandAlignProperties(bigTiff, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    bigTiff->signal_toggled().connect( sigc::mem_fun(*this, &SaveFormatPanel::formatChanged));
+    bigTiff->show_all();
+
 
     // ---------------------  MAIN BOX
 
@@ -114,13 +119,11 @@ SaveFormatPanel::SaveFormatPanel () : listener (nullptr)
     attach (*hb1, 0, 0, 1, 1);
     attach (*jpegOpts, 0, 1, 1, 1);
     attach (*tiffUncompressed, 0, 2, 1, 1);
+    attach (*bigTiff, 0, 3, 1, 1);
     attach (*savesPP, 0, 4, 1, 2);
 }
-SaveFormatPanel::~SaveFormatPanel ()
-{
-    delete jpegQual;
-    delete tiffUncompressed;
-}
+
+SaveFormatPanel::~SaveFormatPanel () = default;
 
 void SaveFormatPanel::init (SaveFormat &sf)
 {
@@ -158,6 +161,7 @@ void SaveFormatPanel::init (SaveFormat &sf)
     jpegQual->setValue(sf.jpegQuality);
     savesPP->set_active(sf.saveParams);
     tiffUncompressed->set_active(sf.tiffUncompressed);
+    bigTiff->set_active(sf.bigTiff);
 
     listener = tmp;
 }
@@ -175,6 +179,7 @@ SaveFormat SaveFormatPanel::getFormat ()
     sf.jpegQuality = jpegQual->getValue();
     sf.jpegSubSamp = jpegSubSamp->get_active_row_number() + 1;
     sf.tiffUncompressed = tiffUncompressed->get_active();
+    sf.bigTiff = bigTiff->get_active();
     sf.saveParams = savesPP->get_active();
 
     return sf;
@@ -193,12 +198,15 @@ void SaveFormatPanel::formatChanged ()
     if (fr == "jpg") {
         jpegOpts->show_all();
         tiffUncompressed->hide();
+        bigTiff->hide();
     } else if (fr == "png") {
         jpegOpts->hide();
         tiffUncompressed->hide();
+        bigTiff->hide();
     } else if (fr == "tif") {
         jpegOpts->hide();
         tiffUncompressed->show_all();
+        bigTiff->show_all();
     }
 
     if (listener) {
