@@ -20,11 +20,10 @@
 #include "guiutils.h"
 #include "rtimage.h"
 
-SensorXTrans::SensorXTrans () : FoldableToolPanel(this, "sensorxtrans", M("TP_RAW_SENSOR_XTRANS_LABEL"))
-{
+const Glib::ustring SensorXTrans::TOOL_NAME = "sensorxtrans";
 
-    packBox = Gtk::manage (new ToolParamBlock ());
-    pack_start (*packBox);
+SensorXTrans::SensorXTrans () : FoldableToolPanel(this, TOOL_NAME, M("TP_RAW_SENSOR_XTRANS_LABEL"))
+{
 
     show_all ();
 }
