@@ -21,18 +21,24 @@
 #include <csignal>
 #include <iostream>
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 #endif
 
 #if STRICT_MUTEX && !NDEBUG
 
-void MyMutex::checkLock ()
+MyMutex::MyMutex() : locked(false) {}
+
+bool MyMutex::checkLock (bool noError)
 {
     if (locked) {
+        if (noError) {
+            return false;
+        }
+
         std::cerr << "MyMutex already locked!" << std::endl;
 
-#ifdef WIN32
+#ifdef _WIN32
         DebugBreak ();
 #else
         raise (SIGTRAP);
@@ -40,6 +46,7 @@ void MyMutex::checkLock ()
     }
 
     locked = true;
+    return true;
 }
 
 void MyMutex::checkUnlock ()
@@ -47,7 +54,7 @@ void MyMutex::checkUnlock ()
     if (!locked) {
         std::cerr << "MyMutex already unlocked!" << std::endl;
 
-#ifdef WIN32
+#ifdef _WIN32
         DebugBreak ();
 #else
         raise (SIGTRAP);
@@ -61,13 +68,18 @@ void MyMutex::checkUnlock ()
 
 #if !TRACE_MYRWMUTEX
 
+MyRWMutex::MyRWMutex() :
+    writerCount(0),
+    readerCount(0)
+{}
+
 void MyReaderLock::acquire ()
 {
     if (locked) {
         return;
     }
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     if (mutex.writerCount == 0) {
         // There's no writer operating, we can increment the writer count which will lock writers.
@@ -76,7 +88,7 @@ void MyReaderLock::acquire ()
         // The writer count is non null, but a reader can be the owner of the writer lock,
         // which will be the case if the reader count is not zero too.
         while (mutex.writerCount != 0) {
-            mutex.cond.wait(mutex.mutex);
+            mutex.cond.wait (lock);
         }
 
         // Then, we can increment the writer count.
@@ -95,7 +107,7 @@ void MyReaderLock::release ()
         return;
     }
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // decrement the writer number first...
     --mutex.readerCount;
@@ -105,7 +117,7 @@ void MyReaderLock::release ()
         --mutex.writerCount;
 
         // ...and signal the next waiting reader/writer that it's free
-        mutex.cond.broadcast ();
+        mutex.cond.notify_all ();
     }
 
     locked = false;
@@ -117,11 +129,11 @@ void MyWriterLock::acquire ()
         return;
     }
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // The writer count is not zero, so we have to wait for it to be zero again...
     while (mutex.writerCount != 0) {
-        mutex.cond.wait (mutex.mutex);
+        mutex.cond.wait (lock);
     }
 
     // ...then we can increment the writer count.
@@ -136,12 +148,12 @@ void MyWriterLock::release ()
         return;
     }
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // Decrement the writer number first...
     if (--mutex.writerCount == 0) {
-        // ...and if the writer count is zero again, we can wake up the next writer or reader.
-        mutex.cond.broadcast ();
+        // ...and if the writer count is zero again, we wake up all of the waiting writer or reader.
+        mutex.cond.notify_all ();
     }
 
     locked = false;
@@ -154,13 +166,20 @@ namespace
 
 std::ostream& trace (const char* file, int line)
 {
-    const auto currentThread = Glib::Threads::Thread::self ();
+    const auto currentThread = std::this_thread::get_id();
 
     return std::cout << currentThread << ":" << file << ":" << line << ": ";
 }
 
 }
 
+MyRWMutex::MyRWMutex() :
+    lastWriterFile(nullptr),
+    lastWriterLine(0),
+    writerCount(0),
+    readerCount(0)
+{}
+
 void MyReaderLock::acquire (const char* file, int line)
 {
     if (locked) {
@@ -170,7 +189,7 @@ void MyReaderLock::acquire (const char* file, int line)
 
     trace (file, line) << "Acquiring MyReaderLock..." << std::endl;
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     if (mutex.writerCount == 0) {
         // There's no writer operating, we can increment the writer count which will lock writers.
@@ -184,13 +203,13 @@ void MyReaderLock::acquire (const char* file, int line)
                                << "\tLast writer file: " << mutex.lastWriterFile << std::endl
                                << "\tLast writer line: " << mutex.lastWriterLine << std::endl;
 
-            mutex.cond.wait(mutex.mutex);
+            mutex.cond.wait (lock);
         }
 
         // Then, we can increment the writer count.
         ++mutex.writerCount;
 
-        mutex.ownerThread = Glib::Threads::Thread::self ();
+        mutex.ownerThread = std::this_thread::get_id ();
         mutex.lastWriterFile = file;
         mutex.lastWriterLine = line;
     }
@@ -211,7 +230,7 @@ void MyReaderLock::release (const char* file, int line)
 
     trace (file, line) << "Releasing MyReaderLock..." << std::endl;
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // decrement the writer number first...
     --mutex.readerCount;
@@ -221,9 +240,9 @@ void MyReaderLock::release (const char* file, int line)
         --mutex.writerCount;
 
         // ...and signal the next waiting reader/writer that it's free
-        mutex.cond.broadcast ();
+        mutex.cond.notify_all ();
 
-        mutex.ownerThread = nullptr;
+        mutex.ownerThread = std::thread::id();
         mutex.lastWriterFile = "";
         mutex.lastWriterLine = 0;
     }
@@ -241,7 +260,7 @@ void MyWriterLock::acquire (const char* file, int line)
 
     trace (file, line) << "Acquiring MyWriterLock..." << std::endl;
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // The writer count is not zero, so we have to wait for it to be zero again...
     while (mutex.writerCount != 0) {
@@ -250,13 +269,13 @@ void MyWriterLock::acquire (const char* file, int line)
                            << "\tLast writer file: " << mutex.lastWriterFile << std::endl
                            << "\tLast writer line: " << mutex.lastWriterLine << std::endl;
 
-        mutex.cond.wait (mutex.mutex);
+        mutex.cond.wait (lock);
     }
 
     // ...then we can increment the writer count.
     ++mutex.writerCount;
 
-    mutex.ownerThread = Glib::Threads::Thread::self ();
+    mutex.ownerThread = std::this_thread::get_id ();
     mutex.lastWriterFile = file;
     mutex.lastWriterLine = line;
 
@@ -273,14 +292,14 @@ void MyWriterLock::release (const char* file, int line)
 
     trace (file, line) << "Releasing MyWriterLock..." << std::endl;
 
-    Glib::Threads::Mutex::Lock lock (mutex.mutex);
+    std::unique_lock<std::mutex> lock (mutex.mutex);
 
     // Decrement the writer number first...
     if (--mutex.writerCount == 0) {
-        // ...and if the writer count is zero again, we can wake up the next writer or reader.
-        mutex.cond.broadcast ();
+        // ...and if the writer count is zero again, we wake up all of the waiting writer or reader.
+        mutex.cond.notify_all ();
 
-        mutex.ownerThread = nullptr;
+        mutex.ownerThread = std::thread::id();
         mutex.lastWriterFile = "";
         mutex.lastWriterLine = 0;
     }
