@@ -18,6 +18,7 @@
  */
 
 #include <atomic>
+#include <memory>
 #include <set>
 
 #include <gtkmm.h>
@@ -45,12 +46,13 @@ public:
 
     struct Job {
         Job(ThumbBrowserEntryBase* tbe, bool* priority, bool upgrade,
-            ThumbImageUpdateListener* listener):
+            bool forceUpgrade, ThumbImageUpdateListener* listener):
             tbe_(tbe),
             /*pparams_(pparams),
             height_(height), */
             priority_(priority),
             upgrade_(upgrade),
+            force_upgrade_(forceUpgrade),
             listener_(listener)
         {}
 
@@ -58,6 +60,7 @@ public:
             tbe_(nullptr),
             priority_(nullptr),
             upgrade_(false),
+            force_upgrade_(false),
             listener_(nullptr)
         {}
 
@@ -66,6 +69,7 @@ public:
         int height_;*/
         bool* priority_;
         bool upgrade_;
+        bool force_upgrade_;
         ThumbImageUpdateListener* listener_;
     };
 
@@ -80,14 +84,14 @@ public:
         threadCount = omp_get_num_procs();
 #endif
 
-        threadPool_ = new Glib::ThreadPool(threadCount, 0);
+        threadPool_.reset(new Glib::ThreadPool(threadCount, 0));
     }
 
-    Glib::ThreadPool* threadPool_;
+    std::unique_ptr<Glib::ThreadPool> threadPool_;
 
-    // Need to be a Glib::Threads::Mutex because used in a Glib::Threads::Cond object...
+    // Need to be a std::mutex because used in a std::condition_variable object...
     // This is the only exceptions along with GThreadMutex (guiutils.cc), MyMutex is used everywhere else
-    Glib::Threads::Mutex mutex_;
+    std::mutex mutex_;
 
     JobList jobs_;
 
@@ -95,7 +99,7 @@ public:
 
     bool inactive_waiting_;
 
-    Glib::Threads::Cond inactive_;
+    std::condition_variable inactive_;
 
     void
     processNextJob()
@@ -103,7 +107,7 @@ public:
         Job j;
 
         {
-            Glib::Threads::Mutex::Lock lock(mutex_);
+            std::lock_guard<std::mutex> lock(mutex_);
 
             // nothing to do; could be jobs have been removed
             if ( jobs_.empty() ) {
@@ -153,8 +157,8 @@ public:
         Thumbnail* thm = j.tbe_->thumbnail;
 
         if ( j.upgrade_ ) {
-            if ( thm->isQuick() ) {
-                img = thm->upgradeThumbImage(thm->getProcParams(), j.tbe_->getPreviewHeight(), scale);
+            if ( thm->isQuick() || j.force_upgrade_ ) {
+                img = thm->upgradeThumbImage(thm->getProcParams(), j.tbe_->getPreviewHeight(), scale, j.force_upgrade_);
             }
         } else {
             img = thm->processThumbImage(thm->getProcParams(), j.tbe_->getPreviewHeight(), scale);
@@ -166,10 +170,10 @@ public:
         }
 
         if ( --active_ == 0 ) {
-            Glib::Threads::Mutex::Lock lock(mutex_);
+            std::lock_guard<std::mutex> lock(mutex_);
             if (inactive_waiting_) {
                 inactive_waiting_ = false;
-                inactive_.broadcast();
+                inactive_.notify_all();
             }
         }
     }
@@ -191,14 +195,14 @@ ThumbImageUpdater::~ThumbImageUpdater() {
     delete impl_;
 }
 
-void ThumbImageUpdater::add(ThumbBrowserEntryBase* tbe, bool* priority, bool upgrade, ThumbImageUpdateListener* l)
+void ThumbImageUpdater::add(ThumbBrowserEntryBase* tbe, bool* priority, bool upgrade, bool forceUpgrade, ThumbImageUpdateListener* l)
 {
     // nobody listening?
     if ( l == nullptr ) {
         return;
     }
 
-    Glib::Threads::Mutex::Lock lock(impl_->mutex_);
+    std::lock_guard<std::mutex> lock(impl_->mutex_);
 
     // look up if an older version is in the queue
     Impl::JobList::iterator i(impl_->jobs_.begin());
@@ -206,7 +210,8 @@ void ThumbImageUpdater::add(ThumbBrowserEntryBase* tbe, bool* priority, bool upg
     for ( ; i != impl_->jobs_.end(); ++i ) {
         if ( i->tbe_ == tbe &&
                 i->listener_ == l &&
-                i->upgrade_ == upgrade ) {
+                i->upgrade_ == upgrade &&
+                i->force_upgrade_ == forceUpgrade) {
             DEBUG("updating job %s", tbe->shortname.c_str());
             // we have one, update queue entry, will be picked up by thread when processed
             /*i->pparams_ = params;
@@ -218,7 +223,7 @@ void ThumbImageUpdater::add(ThumbBrowserEntryBase* tbe, bool* priority, bool upg
 
     // create a new job and append to queue
     DEBUG("queueing job %s", tbe->shortname.c_str());
-    impl_->jobs_.push_back(Impl::Job(tbe, priority, upgrade, l));
+    impl_->jobs_.push_back(Impl::Job(tbe, priority, upgrade, forceUpgrade, l));
 
     DEBUG("adding run request %s", tbe->shortname.c_str());
     impl_->threadPool_->push(sigc::mem_fun(*impl_, &ThumbImageUpdater::Impl::processNextJob));
@@ -230,7 +235,7 @@ void ThumbImageUpdater::removeJobs(ThumbImageUpdateListener* listener)
     DEBUG("removeJobs(%p)", listener);
 
     {
-        Glib::Threads::Mutex::Lock lock(impl_->mutex_);
+        std::lock_guard<std::mutex> lock(impl_->mutex_);
 
         for( Impl::JobList::iterator i(impl_->jobs_.begin()); i != impl_->jobs_.end(); ) {
             if (i->listener_ == listener) {
@@ -246,9 +251,9 @@ void ThumbImageUpdater::removeJobs(ThumbImageUpdateListener* listener)
     while ( impl_->active_ != 0 ) {
         DEBUG("waiting for running jobs1");
         {
-            Glib::Threads::Mutex::Lock lock(impl_->mutex_);
+            std::unique_lock<std::mutex> lock(impl_->mutex_);
             impl_->inactive_waiting_ = true;
-            impl_->inactive_.wait(impl_->mutex_);
+            impl_->inactive_.wait(lock);
         }
     }
 }
@@ -258,7 +263,7 @@ void ThumbImageUpdater::removeAllJobs()
     DEBUG("stop");
 
     {
-        Glib::Threads::Mutex::Lock lock(impl_->mutex_);
+        std::lock_guard<std::mutex> lock(impl_->mutex_);
 
         impl_->jobs_.clear();
     }
@@ -266,9 +271,9 @@ void ThumbImageUpdater::removeAllJobs()
     while ( impl_->active_ != 0 ) {
         DEBUG("waiting for running jobs2");
         {
-            Glib::Threads::Mutex::Lock lock(impl_->mutex_);
+            std::unique_lock<std::mutex> lock(impl_->mutex_);
             impl_->inactive_waiting_ = true;
-            impl_->inactive_.wait(impl_->mutex_);
+            impl_->inactive_.wait(lock);
         }
     }
 }
