@@ -21,7 +21,6 @@
 
 #include "guiutils.h"
 #include "options.h"
-#include "rtimage.h"
 #include "rtscalable.h"
 #include "toollocationpref.h"
 #include "toolpanelcoord.h"
@@ -279,12 +278,9 @@ ListEditButtons::ListEditButtons(Gtk::TreeView &list, Glib::RefPtr<Gtk::ListStor
     assert(list.get_model() == listStore);
 
     // Set button images.
-    RTImage *image_button_up = Gtk::manage(new RTImage("arrow-up-small.png"));
-    RTImage *image_button_down = Gtk::manage(new RTImage("arrow-down-small.png"));
-    RTImage *image_button_remove = Gtk::manage(new RTImage("remove-small.png"));
-    buttonUp.set_image(*image_button_up);
-    buttonDown.set_image(*image_button_down);
-    buttonRemove.set_image(*image_button_remove);
+    buttonUp.set_image_from_icon_name("arrow-up-small");
+    buttonDown.set_image_from_icon_name("arrow-down-small");
+    buttonRemove.set_image_from_icon_name("remove-small");
 
     // Connect signals for changing button sensitivity.
     const auto on_list_sel_changed_fun = sigc::mem_fun(
@@ -540,12 +536,10 @@ ToolLocationPreference::Impl::Impl(Options &options) :
     // Tool list.
     toolListViewPtr->append_column(toolListViewColumnToolName);
     toolListViewColumnToolName.pack_start(toolListCellRendererToolName);
-    toolListViewColumnToolName.set_expand();
     toolListViewColumnToolName.set_renderer(
         toolListCellRendererToolName, toolListColumns.toolName);
     toolListViewPtr->append_column(toolListViewColumnFavorite);
-    toolListViewColumnFavorite.pack_start(toolListCellRendererFavorite);
-    toolListViewColumnFavorite.set_expand(false);
+    toolListViewColumnFavorite.pack_start(toolListCellRendererFavorite, false);
     toolListViewColumnFavorite.set_renderer(
         toolListCellRendererFavorite, toolListColumns.isFavorite);
     toolListViewColumnFavorite.add_attribute(
@@ -720,20 +714,20 @@ ToolLocationPreference::ToolLocationPreference(Options &options) :
     Gtk::Grid *layout_grid = Gtk::manage(new Gtk::Grid());
     layout_grid->set_column_spacing(4);
     layout_grid->set_row_spacing(4);
-    add(*layout_grid);
+    layout_grid->set_column_homogeneous(true);
+    pack_start(*layout_grid);
 
     // Tool list.
     Gtk::Frame *tool_list_frame = Gtk::manage(new Gtk::Frame(
         M("PREFERENCES_TOOLPANEL_AVAILABLETOOLS")));
     Gtk::ScrolledWindow *tool_list_scrolled_window =
         Gtk::manage(new Gtk::ScrolledWindow());
-    tool_list_scrolled_window->set_min_content_width(
-        400 * (RTScalable::getTweakedDPI() / RTScalable::baseDPI));
+    tool_list_scrolled_window->set_min_content_width(RTScalable::scalePixelSize(400));
     layout_grid->attach_next_to(*tool_list_frame, Gtk::PositionType::POS_RIGHT, 1, 1);
     tool_list_frame->add(*tool_list_scrolled_window);
     tool_list_scrolled_window->add(*impl->toolListViewPtr);
     setExpandAlignProperties(
-        tool_list_frame, false, true, Gtk::ALIGN_START, Gtk::ALIGN_FILL);
+        tool_list_frame, true, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
 
     // Favorites list.
     Gtk::Frame *favorites_frame = Gtk::manage(new Gtk::Frame(
@@ -741,15 +735,14 @@ ToolLocationPreference::ToolLocationPreference(Options &options) :
     Gtk::Box *favorites_box = Gtk::manage(new Gtk::Box());
     Gtk::ScrolledWindow *favorites_list_scrolled_window =
         Gtk::manage(new Gtk::ScrolledWindow());
-    favorites_list_scrolled_window->set_min_content_width(
-        300 * (RTScalable::getTweakedDPI() / RTScalable::baseDPI));
+    favorites_list_scrolled_window->set_min_content_width(RTScalable::scalePixelSize(400));
     layout_grid->attach_next_to(*favorites_frame, Gtk::PositionType::POS_RIGHT, 1, 1);
     favorites_box->pack_start(impl->favoritesListEditButtons, false, false);
-    favorites_box->pack_start(*favorites_list_scrolled_window, false, false);
+    favorites_box->pack_start(*favorites_list_scrolled_window, true, true);
     favorites_frame->add(*favorites_box);
     favorites_list_scrolled_window->add(*impl->favoritesViewPtr);
     setExpandAlignProperties(
-        favorites_frame, false, true, Gtk::ALIGN_START, Gtk::ALIGN_FILL);
+        favorites_frame, true, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
 
     // General options.
     layout_grid->attach_next_to(
